Package: SEERaBomb
Title: SEER and Atomic Bomb Survivor Data Analysis Tools
Version: 2019.2
Date: 2019-12-12
Description: Creates SEER (Surveillance, Epidemiology and End Results) and 
    A-bomb data binaries from ASCII sources and provides tools for estimating
    SEER second cancer risks. Methods are described in <doi:10.1038/leu.2015.258>.
Authors@R: c(person("Tomas", "Radivoyevitch", role = c("aut", "cre"),
                     email = "radivot@ccf.org"),
              person("R.", "Molenaar", role = "ctb",
                     email = "r.j.molenaar@amc.uva.nl"))
Depends: dplyr, ggplot2, rgl, demography
Suggests: bbmle
License: GPL (>= 2)
Imports: Rcpp (>= 0.11.3), reshape2, mgcv, tibble, LaF, DBI, RSQLite,
        openxlsx, WriteXLS, labelled, scales, forcats, purrr,readr,
        tidyr, stringr, plyr, survival
LinkingTo: Rcpp
LazyData: yes
URL: http://epbi-radivot.cwru.edu/SEERaBomb/SEERaBomb.html
NeedsCompilation: yes
Packaged: 2019-12-12 18:25:36 UTC; radivot
Author: Tomas Radivoyevitch [aut, cre],
  R. Molenaar [ctb]
Maintainer: Tomas Radivoyevitch <radivot@ccf.org>
Repository: CRAN
Date/Publication: 2019-12-12 18:50:03 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 14:02:27 UTC; unix
Archs: SEERaBomb.so.dSYM
