useDynLib(SEERaBomb, .registration = TRUE)
#import(dbplyr)  ## too many warnings, so let user of mkSEER figure out to install this
import(dplyr)  ## depends
import(ggplot2)  ## depends
#import(tibble)  ## depends
import(demography)  ## depends
#import(LaF,RSQLite,rgl,XLConnect) ## needed less critically but for too many functions to list
import(LaF,RSQLite,rgl,openxlsx,labelled) ## needed less critically but for too many functions to list
importFrom(Rcpp, evalCpp)
importFrom(survival, survfit,Surv)
importFrom(DBI, dbDriver)
importFrom(mgcv, gam,s,ti)
importFrom(plyr, ldply)
importFrom(WriteXLS, WriteXLS)
importFrom(reshape2, melt, acast,dcast)
importFrom(scales, comma_format)
importFrom(forcats, as_factor)
importFrom(purrr, map,pmap)
importFrom(readr, read_table)
importFrom(tidyr, separate,gather,spread,unnest)
importFrom(tibble, as_tibble)
importFrom(stringr, str_replace_all,str_to_title,str_detect)
importFrom("stats","quantile", "qpois", "D", "median", "qchisq", "qt", "rexp", "rpois", "runif", "var", "weighted.mean","lm","predict")
importFrom("utils", "data", "head", "read.csv", "tail")
exportPattern("^[[:alpha:]]+")
##S3method(autoplot,seerSet)
S3method(summary,seerSet)
S3method(print,seerSet.summary)
